@@ -111,7 +111,7 @@ ghex_window_drag_data_received(GtkWidget *widget,
                                              GTK_MESSAGE_ERROR,
                                              GTK_BUTTONS_OK,
                                              _("Can not open file:\n%s"),
-                                             *filename);
+                                             filename);
                 gtk_widget_show(dlg);
                 gtk_dialog_run(GTK_DIALOG(dlg));
                 gtk_widget_destroy(dlg);
@@ -512,7 +512,7 @@ ghex_window_new(void)
     win->uic = uic;
 	bonobo_ui_component_set_container(uic, BONOBO_OBJREF(ui_container),
                                       NULL);
-	bonobo_ui_util_set_ui(uic, NULL, "ghex-ui.xml", "GHex", NULL);
+	bonobo_ui_util_set_ui(uic, PREFIX, "ghex-ui.xml", "GHex", NULL);
 	bonobo_ui_component_add_verb_list_with_data(uic, ghex_verbs, win);
     
 	bonobo_ui_component_add_listener (uic, "Bytes",
@@ -1243,7 +1243,7 @@ ghex_window_ok_to_close(GHexWindow *win)
                 return FALSE;
             }
             else if(!hex_document_write(doc)) {
-                display_error_dialog(win, _("An error occured while saving file!"));
+                display_error_dialog(win, _("An error occurred while saving file!"));
 				return FALSE;
 			}
 		}
